Class: PulpMavenClient::ContentArtifactApi
- Inherits:
-
Object
- Object
- PulpMavenClient::ContentArtifactApi
- Defined in:
- lib/pulp_maven_client/api/content_artifact_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create(relative_path, opts = {}) ⇒ AsyncOperationResponse
Create a maven artifact Trigger an asynchronous task to create content,optionally create new repository version.
-
#create_with_http_info(relative_path, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Create a maven artifact Trigger an asynchronous task to create content,optionally create new repository version.
-
#initialize(api_client = ApiClient.default) ⇒ ContentArtifactApi
constructor
A new instance of ContentArtifactApi.
-
#list(opts = {}) ⇒ PaginatedmavenMavenArtifactResponseList
List maven artifacts A ViewSet for MavenArtifact.
-
#list_with_http_info(opts = {}) ⇒ Array<(PaginatedmavenMavenArtifactResponseList, Integer, Hash)>
List maven artifacts A ViewSet for MavenArtifact.
-
#read(maven_maven_artifact_href, opts = {}) ⇒ MavenMavenArtifactResponse
Inspect a maven artifact A ViewSet for MavenArtifact.
-
#read_with_http_info(maven_maven_artifact_href, opts = {}) ⇒ Array<(MavenMavenArtifactResponse, Integer, Hash)>
Inspect a maven artifact A ViewSet for MavenArtifact.
-
#set_label(maven_maven_artifact_href, set_label, opts = {}) ⇒ SetLabelResponse
Set a label Set a single pulp_label on the object to a specific value or null.
-
#set_label_with_http_info(maven_maven_artifact_href, set_label, opts = {}) ⇒ Array<(SetLabelResponse, Integer, Hash)>
Set a label Set a single pulp_label on the object to a specific value or null.
-
#unset_label(maven_maven_artifact_href, unset_label, opts = {}) ⇒ UnsetLabelResponse
Unset a label Unset a single pulp_label on the object.
-
#unset_label_with_http_info(maven_maven_artifact_href, unset_label, opts = {}) ⇒ Array<(UnsetLabelResponse, Integer, Hash)>
Unset a label Unset a single pulp_label on the object.
-
#upload(relative_path, opts = {}) ⇒ MavenMavenArtifactResponse
Upload a Maven artifact synchronously.
-
#upload_with_http_info(relative_path, opts = {}) ⇒ Array<(MavenMavenArtifactResponse, Integer, Hash)>
Upload a Maven artifact synchronously.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ContentArtifactApi
Returns a new instance of ContentArtifactApi.
19 20 21 |
# File 'lib/pulp_maven_client/api/content_artifact_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pulp_maven_client/api/content_artifact_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create(relative_path, opts = {}) ⇒ AsyncOperationResponse
Create a maven artifact Trigger an asynchronous task to create content,optionally create new repository version.
36 37 38 39 |
# File 'lib/pulp_maven_client/api/content_artifact_api.rb', line 36 def create(relative_path, opts = {}) data, _status_code, _headers = create_with_http_info(relative_path, opts) data end |
#create_with_http_info(relative_path, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Create a maven artifact Trigger an asynchronous task to create content,optionally create new repository version.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/pulp_maven_client/api/content_artifact_api.rb', line 55 def create_with_http_info(relative_path, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContentArtifactApi.create ...' end # verify the required parameter 'relative_path' is set if @api_client.config.client_side_validation && relative_path.nil? fail ArgumentError, "Missing the required parameter 'relative_path' when calling ContentArtifactApi.create" end if @api_client.config.client_side_validation && relative_path.to_s.length < 1 fail ArgumentError, 'invalid value for "relative_path" when calling ContentArtifactApi.create, the character length must be great than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'file_url'].nil? && opts[:'file_url'].to_s.length < 1 fail ArgumentError, 'invalid value for "opts[:"file_url"]" when calling ContentArtifactApi.create, the character length must be great than or equal to 1.' end # resource path local_var_path = '/pulp/api/v3/content/maven/artifact/' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['multipart/form-data', 'application/x-www-form-urlencoded']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} form_params['relative_path'] = relative_path form_params['repository'] = opts[:'repository'] if !opts[:'repository'].nil? form_params['overwrite'] = opts[:'overwrite'] if !opts[:'overwrite'].nil? form_params['pulp_labels'] = opts[:'pulp_labels'] if !opts[:'pulp_labels'].nil? form_params['artifact'] = opts[:'artifact'] if !opts[:'artifact'].nil? form_params['file'] = opts[:'file'] if !opts[:'file'].nil? form_params['upload'] = opts[:'upload'] if !opts[:'upload'].nil? form_params['file_url'] = opts[:'file_url'] if !opts[:'file_url'].nil? form_params['downloader_config'] = opts[:'downloader_config'] if !opts[:'downloader_config'].nil? # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"ContentArtifactApi.create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContentArtifactApi#create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list(opts = {}) ⇒ PaginatedmavenMavenArtifactResponseList
List maven artifacts A ViewSet for MavenArtifact.
149 150 151 152 |
# File 'lib/pulp_maven_client/api/content_artifact_api.rb', line 149 def list(opts = {}) data, _status_code, _headers = list_with_http_info(opts) data end |
#list_with_http_info(opts = {}) ⇒ Array<(PaginatedmavenMavenArtifactResponseList, Integer, Hash)>
List maven artifacts A ViewSet for MavenArtifact.
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/pulp_maven_client/api/content_artifact_api.rb', line 177 def list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContentArtifactApi.list ...' end allowable_values = ["-artifact_id", "-filename", "-group_id", "-pk", "-pulp_created", "-pulp_id", "-pulp_labels", "-pulp_last_updated", "-pulp_type", "-timestamp_of_interest", "-upstream_id", "-version", "artifact_id", "filename", "group_id", "pk", "pulp_created", "pulp_id", "pulp_labels", "pulp_last_updated", "pulp_type", "timestamp_of_interest", "upstream_id", "version"] if @api_client.config.client_side_validation && opts[:'ordering'] && !opts[:'ordering'].all? { |item| allowable_values.include?(item) } fail ArgumentError, "invalid value for \"ordering\", must include one of #{allowable_values}" end # resource path local_var_path = '/pulp/api/v3/content/maven/artifact/' # query parameters query_params = opts[:query_params] || {} query_params[:'artifact_id'] = opts[:'artifact_id'] if !opts[:'artifact_id'].nil? query_params[:'filename'] = opts[:'filename'] if !opts[:'filename'].nil? query_params[:'group_id'] = opts[:'group_id'] if !opts[:'group_id'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'ordering'] = @api_client.build_collection_param(opts[:'ordering'], :csv) if !opts[:'ordering'].nil? query_params[:'orphaned_for'] = opts[:'orphaned_for'] if !opts[:'orphaned_for'].nil? query_params[:'prn__in'] = @api_client.build_collection_param(opts[:'prn__in'], :csv) if !opts[:'prn__in'].nil? query_params[:'pulp_href__in'] = @api_client.build_collection_param(opts[:'pulp_href__in'], :csv) if !opts[:'pulp_href__in'].nil? query_params[:'pulp_id__in'] = @api_client.build_collection_param(opts[:'pulp_id__in'], :csv) if !opts[:'pulp_id__in'].nil? query_params[:'pulp_label_select'] = opts[:'pulp_label_select'] if !opts[:'pulp_label_select'].nil? query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil? query_params[:'repository_version'] = opts[:'repository_version'] if !opts[:'repository_version'].nil? query_params[:'repository_version_added'] = opts[:'repository_version_added'] if !opts[:'repository_version_added'].nil? query_params[:'repository_version_removed'] = opts[:'repository_version_removed'] if !opts[:'repository_version_removed'].nil? query_params[:'version'] = opts[:'version'] if !opts[:'version'].nil? query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil? query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PaginatedmavenMavenArtifactResponseList' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"ContentArtifactApi.list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContentArtifactApi#list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#read(maven_maven_artifact_href, opts = {}) ⇒ MavenMavenArtifactResponse
Inspect a maven artifact A ViewSet for MavenArtifact.
252 253 254 255 |
# File 'lib/pulp_maven_client/api/content_artifact_api.rb', line 252 def read(maven_maven_artifact_href, opts = {}) data, _status_code, _headers = read_with_http_info(maven_maven_artifact_href, opts) data end |
#read_with_http_info(maven_maven_artifact_href, opts = {}) ⇒ Array<(MavenMavenArtifactResponse, Integer, Hash)>
Inspect a maven artifact A ViewSet for MavenArtifact.
265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/pulp_maven_client/api/content_artifact_api.rb', line 265 def read_with_http_info(maven_maven_artifact_href, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContentArtifactApi.read ...' end # verify the required parameter 'maven_maven_artifact_href' is set if @api_client.config.client_side_validation && maven_maven_artifact_href.nil? fail ArgumentError, "Missing the required parameter 'maven_maven_artifact_href' when calling ContentArtifactApi.read" end # resource path local_var_path = '{maven_maven_artifact_href}'.sub('{' + 'maven_maven_artifact_href' + '}', CGI.escape(maven_maven_artifact_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil? query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'MavenMavenArtifactResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"ContentArtifactApi.read", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContentArtifactApi#read\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#set_label(maven_maven_artifact_href, set_label, opts = {}) ⇒ SetLabelResponse
Set a label Set a single pulp_label on the object to a specific value or null.
323 324 325 326 |
# File 'lib/pulp_maven_client/api/content_artifact_api.rb', line 323 def set_label(maven_maven_artifact_href, set_label, opts = {}) data, _status_code, _headers = set_label_with_http_info(maven_maven_artifact_href, set_label, opts) data end |
#set_label_with_http_info(maven_maven_artifact_href, set_label, opts = {}) ⇒ Array<(SetLabelResponse, Integer, Hash)>
Set a label Set a single pulp_label on the object to a specific value or null.
335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 |
# File 'lib/pulp_maven_client/api/content_artifact_api.rb', line 335 def set_label_with_http_info(maven_maven_artifact_href, set_label, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContentArtifactApi.set_label ...' end # verify the required parameter 'maven_maven_artifact_href' is set if @api_client.config.client_side_validation && maven_maven_artifact_href.nil? fail ArgumentError, "Missing the required parameter 'maven_maven_artifact_href' when calling ContentArtifactApi.set_label" end # verify the required parameter 'set_label' is set if @api_client.config.client_side_validation && set_label.nil? fail ArgumentError, "Missing the required parameter 'set_label' when calling ContentArtifactApi.set_label" end # resource path local_var_path = '{maven_maven_artifact_href}set_label/'.sub('{' + 'maven_maven_artifact_href' + '}', CGI.escape(maven_maven_artifact_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(set_label) # return_type return_type = opts[:debug_return_type] || 'SetLabelResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"ContentArtifactApi.set_label", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContentArtifactApi#set_label\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#unset_label(maven_maven_artifact_href, unset_label, opts = {}) ⇒ UnsetLabelResponse
Unset a label Unset a single pulp_label on the object.
400 401 402 403 |
# File 'lib/pulp_maven_client/api/content_artifact_api.rb', line 400 def unset_label(maven_maven_artifact_href, unset_label, opts = {}) data, _status_code, _headers = unset_label_with_http_info(maven_maven_artifact_href, unset_label, opts) data end |
#unset_label_with_http_info(maven_maven_artifact_href, unset_label, opts = {}) ⇒ Array<(UnsetLabelResponse, Integer, Hash)>
Unset a label Unset a single pulp_label on the object.
412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 |
# File 'lib/pulp_maven_client/api/content_artifact_api.rb', line 412 def unset_label_with_http_info(maven_maven_artifact_href, unset_label, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContentArtifactApi.unset_label ...' end # verify the required parameter 'maven_maven_artifact_href' is set if @api_client.config.client_side_validation && maven_maven_artifact_href.nil? fail ArgumentError, "Missing the required parameter 'maven_maven_artifact_href' when calling ContentArtifactApi.unset_label" end # verify the required parameter 'unset_label' is set if @api_client.config.client_side_validation && unset_label.nil? fail ArgumentError, "Missing the required parameter 'unset_label' when calling ContentArtifactApi.unset_label" end # resource path local_var_path = '{maven_maven_artifact_href}unset_label/'.sub('{' + 'maven_maven_artifact_href' + '}', CGI.escape(maven_maven_artifact_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(unset_label) # return_type return_type = opts[:debug_return_type] || 'UnsetLabelResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"ContentArtifactApi.unset_label", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContentArtifactApi#unset_label\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#upload(relative_path, opts = {}) ⇒ MavenMavenArtifactResponse
Upload a Maven artifact synchronously. Synchronously upload a Maven artifact.
484 485 486 487 |
# File 'lib/pulp_maven_client/api/content_artifact_api.rb', line 484 def upload(relative_path, opts = {}) data, _status_code, _headers = upload_with_http_info(relative_path, opts) data end |
#upload_with_http_info(relative_path, opts = {}) ⇒ Array<(MavenMavenArtifactResponse, Integer, Hash)>
Upload a Maven artifact synchronously. Synchronously upload a Maven artifact.
503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 |
# File 'lib/pulp_maven_client/api/content_artifact_api.rb', line 503 def upload_with_http_info(relative_path, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContentArtifactApi.upload ...' end # verify the required parameter 'relative_path' is set if @api_client.config.client_side_validation && relative_path.nil? fail ArgumentError, "Missing the required parameter 'relative_path' when calling ContentArtifactApi.upload" end if @api_client.config.client_side_validation && relative_path.to_s.length < 1 fail ArgumentError, 'invalid value for "relative_path" when calling ContentArtifactApi.upload, the character length must be great than or equal to 1.' end if @api_client.config.client_side_validation && !opts[:'file_url'].nil? && opts[:'file_url'].to_s.length < 1 fail ArgumentError, 'invalid value for "opts[:"file_url"]" when calling ContentArtifactApi.upload, the character length must be great than or equal to 1.' end # resource path local_var_path = '/pulp/api/v3/content/maven/artifact/upload/' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['multipart/form-data', 'application/x-www-form-urlencoded']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} form_params['relative_path'] = relative_path form_params['repository'] = opts[:'repository'] if !opts[:'repository'].nil? form_params['overwrite'] = opts[:'overwrite'] if !opts[:'overwrite'].nil? form_params['pulp_labels'] = opts[:'pulp_labels'] if !opts[:'pulp_labels'].nil? form_params['artifact'] = opts[:'artifact'] if !opts[:'artifact'].nil? form_params['file'] = opts[:'file'] if !opts[:'file'].nil? form_params['upload'] = opts[:'upload'] if !opts[:'upload'].nil? form_params['file_url'] = opts[:'file_url'] if !opts[:'file_url'].nil? form_params['downloader_config'] = opts[:'downloader_config'] if !opts[:'downloader_config'].nil? # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'MavenMavenArtifactResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"ContentArtifactApi.upload", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContentArtifactApi#upload\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |