Class: PulpMavenClient::RepositoriesMavenApi
- Inherits:
-
Object
- Object
- PulpMavenClient::RepositoriesMavenApi
- Defined in:
- lib/pulp_maven_client/api/repositories_maven_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#add_cached_content(maven_maven_repository_href, repository_add_cached_content, opts = {}) ⇒ AsyncOperationResponse
Add cached content Trigger an asynchronous task to add cached content to a repository.
-
#add_cached_content_with_http_info(maven_maven_repository_href, repository_add_cached_content, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Add cached content Trigger an asynchronous task to add cached content to a repository.
-
#add_role(maven_maven_repository_href, nested_role, opts = {}) ⇒ NestedRoleResponse
Add a role Add a role for this object to users/groups.
-
#add_role_with_http_info(maven_maven_repository_href, nested_role, opts = {}) ⇒ Array<(NestedRoleResponse, Integer, Hash)>
Add a role Add a role for this object to users/groups.
-
#create(maven_maven_repository, opts = {}) ⇒ MavenMavenRepositoryResponse
Create a maven repository A ViewSet for MavenRepository.
-
#create_with_http_info(maven_maven_repository, opts = {}) ⇒ Array<(MavenMavenRepositoryResponse, Integer, Hash)>
Create a maven repository A ViewSet for MavenRepository.
-
#delete(maven_maven_repository_href, opts = {}) ⇒ AsyncOperationResponse
Delete a maven repository Trigger an asynchronous delete task.
-
#delete_with_http_info(maven_maven_repository_href, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Delete a maven repository Trigger an asynchronous delete task.
-
#initialize(api_client = ApiClient.default) ⇒ RepositoriesMavenApi
constructor
A new instance of RepositoriesMavenApi.
-
#list(opts = {}) ⇒ PaginatedmavenMavenRepositoryResponseList
List maven repositorys A ViewSet for MavenRepository.
-
#list_roles(maven_maven_repository_href, opts = {}) ⇒ ObjectRolesResponse
List roles List roles assigned to this object.
-
#list_roles_with_http_info(maven_maven_repository_href, opts = {}) ⇒ Array<(ObjectRolesResponse, Integer, Hash)>
List roles List roles assigned to this object.
-
#list_with_http_info(opts = {}) ⇒ Array<(PaginatedmavenMavenRepositoryResponseList, Integer, Hash)>
List maven repositorys A ViewSet for MavenRepository.
-
#modify(maven_maven_repository_href, repository_add_remove_content, opts = {}) ⇒ AsyncOperationResponse
Modify Repository Content Trigger an asynchronous task to create a new repository version.
-
#modify_with_http_info(maven_maven_repository_href, repository_add_remove_content, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Modify Repository Content Trigger an asynchronous task to create a new repository version.
-
#my_permissions(maven_maven_repository_href, opts = {}) ⇒ MyPermissionsResponse
List user permissions List permissions available to the current user on this object.
-
#my_permissions_with_http_info(maven_maven_repository_href, opts = {}) ⇒ Array<(MyPermissionsResponse, Integer, Hash)>
List user permissions List permissions available to the current user on this object.
-
#partial_update(maven_maven_repository_href, patchedmaven_maven_repository, opts = {}) ⇒ MavenMavenRepositoryResponse
Update a maven repository Update the entity partially and trigger an asynchronous task if necessary.
-
#partial_update_with_http_info(maven_maven_repository_href, patchedmaven_maven_repository, opts = {}) ⇒ Array<(MavenMavenRepositoryResponse, Integer, Hash)>
Update a maven repository Update the entity partially and trigger an asynchronous task if necessary.
-
#read(maven_maven_repository_href, opts = {}) ⇒ MavenMavenRepositoryResponse
Inspect a maven repository A ViewSet for MavenRepository.
-
#read_with_http_info(maven_maven_repository_href, opts = {}) ⇒ Array<(MavenMavenRepositoryResponse, Integer, Hash)>
Inspect a maven repository A ViewSet for MavenRepository.
-
#remove_role(maven_maven_repository_href, nested_role, opts = {}) ⇒ NestedRoleResponse
Remove a role Remove a role for this object from users/groups.
-
#remove_role_with_http_info(maven_maven_repository_href, nested_role, opts = {}) ⇒ Array<(NestedRoleResponse, Integer, Hash)>
Remove a role Remove a role for this object from users/groups.
-
#repair_metadata(maven_maven_repository_href, opts = {}) ⇒ AsyncOperationResponse
Repair metadata Trigger an asynchronous task to regenerate all maven-metadata.xml files and their checksums for every artifact in the repository.
-
#repair_metadata_with_http_info(maven_maven_repository_href, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Repair metadata Trigger an asynchronous task to regenerate all maven-metadata.xml files and their checksums for every artifact in the repository.
-
#set_label(maven_maven_repository_href, set_label, opts = {}) ⇒ SetLabelResponse
Set a label Set a single pulp_label on the object to a specific value or null.
-
#set_label_with_http_info(maven_maven_repository_href, set_label, opts = {}) ⇒ Array<(SetLabelResponse, Integer, Hash)>
Set a label Set a single pulp_label on the object to a specific value or null.
-
#unset_label(maven_maven_repository_href, unset_label, opts = {}) ⇒ UnsetLabelResponse
Unset a label Unset a single pulp_label on the object.
-
#unset_label_with_http_info(maven_maven_repository_href, unset_label, opts = {}) ⇒ Array<(UnsetLabelResponse, Integer, Hash)>
Unset a label Unset a single pulp_label on the object.
-
#update(maven_maven_repository_href, maven_maven_repository, opts = {}) ⇒ MavenMavenRepositoryResponse
Update a maven repository Update the entity and trigger an asynchronous task if necessary.
-
#update_with_http_info(maven_maven_repository_href, maven_maven_repository, opts = {}) ⇒ Array<(MavenMavenRepositoryResponse, Integer, Hash)>
Update a maven repository Update the entity and trigger an asynchronous task if necessary.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ RepositoriesMavenApi
Returns a new instance of RepositoriesMavenApi.
19 20 21 |
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#add_cached_content(maven_maven_repository_href, repository_add_cached_content, opts = {}) ⇒ AsyncOperationResponse
Add cached content Trigger an asynchronous task to add cached content to a repository.
29 30 31 32 |
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 29 def add_cached_content(maven_maven_repository_href, repository_add_cached_content, opts = {}) data, _status_code, _headers = add_cached_content_with_http_info(maven_maven_repository_href, repository_add_cached_content, opts) data end |
#add_cached_content_with_http_info(maven_maven_repository_href, repository_add_cached_content, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Add cached content Trigger an asynchronous task to add cached content to a repository.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 41 def add_cached_content_with_http_info(maven_maven_repository_href, repository_add_cached_content, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesMavenApi.add_cached_content ...' end # verify the required parameter 'maven_maven_repository_href' is set if @api_client.config.client_side_validation && maven_maven_repository_href.nil? fail ArgumentError, "Missing the required parameter 'maven_maven_repository_href' when calling RepositoriesMavenApi.add_cached_content" end # verify the required parameter 'repository_add_cached_content' is set if @api_client.config.client_side_validation && repository_add_cached_content.nil? fail ArgumentError, "Missing the required parameter 'repository_add_cached_content' when calling RepositoriesMavenApi.add_cached_content" end # resource path local_var_path = '{maven_maven_repository_href}add_cached_content/'.sub('{' + 'maven_maven_repository_href' + '}', CGI.escape(maven_maven_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(repository_add_cached_content) # return_type return_type = opts[:debug_return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"RepositoriesMavenApi.add_cached_content", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesMavenApi#add_cached_content\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#add_role(maven_maven_repository_href, nested_role, opts = {}) ⇒ NestedRoleResponse
Add a role Add a role for this object to users/groups.
106 107 108 109 |
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 106 def add_role(maven_maven_repository_href, nested_role, opts = {}) data, _status_code, _headers = add_role_with_http_info(maven_maven_repository_href, nested_role, opts) data end |
#add_role_with_http_info(maven_maven_repository_href, nested_role, opts = {}) ⇒ Array<(NestedRoleResponse, Integer, Hash)>
Add a role Add a role for this object to users/groups.
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 118 def add_role_with_http_info(maven_maven_repository_href, nested_role, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesMavenApi.add_role ...' end # verify the required parameter 'maven_maven_repository_href' is set if @api_client.config.client_side_validation && maven_maven_repository_href.nil? fail ArgumentError, "Missing the required parameter 'maven_maven_repository_href' when calling RepositoriesMavenApi.add_role" end # verify the required parameter 'nested_role' is set if @api_client.config.client_side_validation && nested_role.nil? fail ArgumentError, "Missing the required parameter 'nested_role' when calling RepositoriesMavenApi.add_role" end # resource path local_var_path = '{maven_maven_repository_href}add_role/'.sub('{' + 'maven_maven_repository_href' + '}', CGI.escape(maven_maven_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(nested_role) # return_type return_type = opts[:debug_return_type] || 'NestedRoleResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"RepositoriesMavenApi.add_role", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesMavenApi#add_role\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create(maven_maven_repository, opts = {}) ⇒ MavenMavenRepositoryResponse
Create a maven repository A ViewSet for MavenRepository.
182 183 184 185 |
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 182 def create(maven_maven_repository, opts = {}) data, _status_code, _headers = create_with_http_info(maven_maven_repository, opts) data end |
#create_with_http_info(maven_maven_repository, opts = {}) ⇒ Array<(MavenMavenRepositoryResponse, Integer, Hash)>
Create a maven repository A ViewSet for MavenRepository.
193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 193 def create_with_http_info(maven_maven_repository, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesMavenApi.create ...' end # verify the required parameter 'maven_maven_repository' is set if @api_client.config.client_side_validation && maven_maven_repository.nil? fail ArgumentError, "Missing the required parameter 'maven_maven_repository' when calling RepositoriesMavenApi.create" end # resource path local_var_path = '/pulp/api/v3/repositories/maven/maven/' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(maven_maven_repository) # return_type return_type = opts[:debug_return_type] || 'MavenMavenRepositoryResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"RepositoriesMavenApi.create", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesMavenApi#create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete(maven_maven_repository_href, opts = {}) ⇒ AsyncOperationResponse
Delete a maven repository Trigger an asynchronous delete task
253 254 255 256 |
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 253 def delete(maven_maven_repository_href, opts = {}) data, _status_code, _headers = delete_with_http_info(maven_maven_repository_href, opts) data end |
#delete_with_http_info(maven_maven_repository_href, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Delete a maven repository Trigger an asynchronous delete task
264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 264 def delete_with_http_info(maven_maven_repository_href, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesMavenApi.delete ...' end # verify the required parameter 'maven_maven_repository_href' is set if @api_client.config.client_side_validation && maven_maven_repository_href.nil? fail ArgumentError, "Missing the required parameter 'maven_maven_repository_href' when calling RepositoriesMavenApi.delete" end # resource path local_var_path = '{maven_maven_repository_href}'.sub('{' + 'maven_maven_repository_href' + '}', CGI.escape(maven_maven_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"RepositoriesMavenApi.delete", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesMavenApi#delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list(opts = {}) ⇒ PaginatedmavenMavenRepositoryResponseList
List maven repositorys A ViewSet for MavenRepository.
356 357 358 359 |
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 356 def list(opts = {}) data, _status_code, _headers = list_with_http_info(opts) data end |
#list_roles(maven_maven_repository_href, opts = {}) ⇒ ObjectRolesResponse
List roles List roles assigned to this object.
499 500 501 502 |
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 499 def list_roles(maven_maven_repository_href, opts = {}) data, _status_code, _headers = list_roles_with_http_info(maven_maven_repository_href, opts) data end |
#list_roles_with_http_info(maven_maven_repository_href, opts = {}) ⇒ Array<(ObjectRolesResponse, Integer, Hash)>
List roles List roles assigned to this object.
512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 |
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 512 def list_roles_with_http_info(maven_maven_repository_href, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesMavenApi.list_roles ...' end # verify the required parameter 'maven_maven_repository_href' is set if @api_client.config.client_side_validation && maven_maven_repository_href.nil? fail ArgumentError, "Missing the required parameter 'maven_maven_repository_href' when calling RepositoriesMavenApi.list_roles" end # resource path local_var_path = '{maven_maven_repository_href}list_roles/'.sub('{' + 'maven_maven_repository_href' + '}', CGI.escape(maven_maven_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil? query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ObjectRolesResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"RepositoriesMavenApi.list_roles", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesMavenApi#list_roles\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_with_http_info(opts = {}) ⇒ Array<(PaginatedmavenMavenRepositoryResponseList, Integer, Hash)>
List maven repositorys A ViewSet for MavenRepository.
404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 |
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 404 def list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesMavenApi.list ...' end allowable_values = ["-description", "-name", "-next_version", "-pk", "-pulp_created", "-pulp_id", "-pulp_labels", "-pulp_last_updated", "-pulp_type", "-retain_checkpoints", "-retain_repo_versions", "-user_hidden", "description", "name", "next_version", "pk", "pulp_created", "pulp_id", "pulp_labels", "pulp_last_updated", "pulp_type", "retain_checkpoints", "retain_repo_versions", "user_hidden"] if @api_client.config.client_side_validation && opts[:'ordering'] && !opts[:'ordering'].all? { |item| allowable_values.include?(item) } fail ArgumentError, "invalid value for \"ordering\", must include one of #{allowable_values}" end # resource path local_var_path = '/pulp/api/v3/repositories/maven/maven/' # query parameters query_params = opts[:query_params] || {} query_params[:'latest_with_content'] = opts[:'latest_with_content'] if !opts[:'latest_with_content'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'name'] = opts[:'name'] if !opts[:'name'].nil? query_params[:'name__contains'] = opts[:'name__contains'] if !opts[:'name__contains'].nil? query_params[:'name__icontains'] = opts[:'name__icontains'] if !opts[:'name__icontains'].nil? query_params[:'name__iexact'] = opts[:'name__iexact'] if !opts[:'name__iexact'].nil? query_params[:'name__in'] = @api_client.build_collection_param(opts[:'name__in'], :csv) if !opts[:'name__in'].nil? query_params[:'name__iregex'] = opts[:'name__iregex'] if !opts[:'name__iregex'].nil? query_params[:'name__istartswith'] = opts[:'name__istartswith'] if !opts[:'name__istartswith'].nil? query_params[:'name__regex'] = opts[:'name__regex'] if !opts[:'name__regex'].nil? query_params[:'name__startswith'] = opts[:'name__startswith'] if !opts[:'name__startswith'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'ordering'] = @api_client.build_collection_param(opts[:'ordering'], :csv) if !opts[:'ordering'].nil? query_params[:'prn__in'] = @api_client.build_collection_param(opts[:'prn__in'], :csv) if !opts[:'prn__in'].nil? query_params[:'pulp_href__in'] = @api_client.build_collection_param(opts[:'pulp_href__in'], :csv) if !opts[:'pulp_href__in'].nil? query_params[:'pulp_id__in'] = @api_client.build_collection_param(opts[:'pulp_id__in'], :csv) if !opts[:'pulp_id__in'].nil? query_params[:'pulp_label_select'] = opts[:'pulp_label_select'] if !opts[:'pulp_label_select'].nil? query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil? query_params[:'remote'] = opts[:'remote'] if !opts[:'remote'].nil? query_params[:'retain_checkpoints'] = opts[:'retain_checkpoints'] if !opts[:'retain_checkpoints'].nil? query_params[:'retain_checkpoints__gt'] = opts[:'retain_checkpoints__gt'] if !opts[:'retain_checkpoints__gt'].nil? query_params[:'retain_checkpoints__gte'] = opts[:'retain_checkpoints__gte'] if !opts[:'retain_checkpoints__gte'].nil? query_params[:'retain_checkpoints__isnull'] = opts[:'retain_checkpoints__isnull'] if !opts[:'retain_checkpoints__isnull'].nil? query_params[:'retain_checkpoints__lt'] = opts[:'retain_checkpoints__lt'] if !opts[:'retain_checkpoints__lt'].nil? query_params[:'retain_checkpoints__lte'] = opts[:'retain_checkpoints__lte'] if !opts[:'retain_checkpoints__lte'].nil? query_params[:'retain_checkpoints__ne'] = opts[:'retain_checkpoints__ne'] if !opts[:'retain_checkpoints__ne'].nil? query_params[:'retain_checkpoints__range'] = @api_client.build_collection_param(opts[:'retain_checkpoints__range'], :csv) if !opts[:'retain_checkpoints__range'].nil? query_params[:'retain_repo_versions'] = opts[:'retain_repo_versions'] if !opts[:'retain_repo_versions'].nil? query_params[:'retain_repo_versions__gt'] = opts[:'retain_repo_versions__gt'] if !opts[:'retain_repo_versions__gt'].nil? query_params[:'retain_repo_versions__gte'] = opts[:'retain_repo_versions__gte'] if !opts[:'retain_repo_versions__gte'].nil? query_params[:'retain_repo_versions__isnull'] = opts[:'retain_repo_versions__isnull'] if !opts[:'retain_repo_versions__isnull'].nil? query_params[:'retain_repo_versions__lt'] = opts[:'retain_repo_versions__lt'] if !opts[:'retain_repo_versions__lt'].nil? query_params[:'retain_repo_versions__lte'] = opts[:'retain_repo_versions__lte'] if !opts[:'retain_repo_versions__lte'].nil? query_params[:'retain_repo_versions__ne'] = opts[:'retain_repo_versions__ne'] if !opts[:'retain_repo_versions__ne'].nil? query_params[:'retain_repo_versions__range'] = @api_client.build_collection_param(opts[:'retain_repo_versions__range'], :csv) if !opts[:'retain_repo_versions__range'].nil? query_params[:'with_content'] = opts[:'with_content'] if !opts[:'with_content'].nil? query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil? query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PaginatedmavenMavenRepositoryResponseList' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"RepositoriesMavenApi.list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesMavenApi#list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#modify(maven_maven_repository_href, repository_add_remove_content, opts = {}) ⇒ AsyncOperationResponse
Modify Repository Content Trigger an asynchronous task to create a new repository version.
570 571 572 573 |
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 570 def modify(maven_maven_repository_href, repository_add_remove_content, opts = {}) data, _status_code, _headers = modify_with_http_info(maven_maven_repository_href, repository_add_remove_content, opts) data end |
#modify_with_http_info(maven_maven_repository_href, repository_add_remove_content, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Modify Repository Content Trigger an asynchronous task to create a new repository version.
582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 |
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 582 def modify_with_http_info(maven_maven_repository_href, repository_add_remove_content, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesMavenApi.modify ...' end # verify the required parameter 'maven_maven_repository_href' is set if @api_client.config.client_side_validation && maven_maven_repository_href.nil? fail ArgumentError, "Missing the required parameter 'maven_maven_repository_href' when calling RepositoriesMavenApi.modify" end # verify the required parameter 'repository_add_remove_content' is set if @api_client.config.client_side_validation && repository_add_remove_content.nil? fail ArgumentError, "Missing the required parameter 'repository_add_remove_content' when calling RepositoriesMavenApi.modify" end # resource path local_var_path = '{maven_maven_repository_href}modify/'.sub('{' + 'maven_maven_repository_href' + '}', CGI.escape(maven_maven_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(repository_add_remove_content) # return_type return_type = opts[:debug_return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"RepositoriesMavenApi.modify", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesMavenApi#modify\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#my_permissions(maven_maven_repository_href, opts = {}) ⇒ MyPermissionsResponse
List user permissions List permissions available to the current user on this object.
648 649 650 651 |
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 648 def (maven_maven_repository_href, opts = {}) data, _status_code, _headers = (maven_maven_repository_href, opts) data end |
#my_permissions_with_http_info(maven_maven_repository_href, opts = {}) ⇒ Array<(MyPermissionsResponse, Integer, Hash)>
List user permissions List permissions available to the current user on this object.
661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 |
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 661 def (maven_maven_repository_href, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesMavenApi.my_permissions ...' end # verify the required parameter 'maven_maven_repository_href' is set if @api_client.config.client_side_validation && maven_maven_repository_href.nil? fail ArgumentError, "Missing the required parameter 'maven_maven_repository_href' when calling RepositoriesMavenApi.my_permissions" end # resource path local_var_path = '{maven_maven_repository_href}my_permissions/'.sub('{' + 'maven_maven_repository_href' + '}', CGI.escape(maven_maven_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil? query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'MyPermissionsResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"RepositoriesMavenApi.my_permissions", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesMavenApi#my_permissions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#partial_update(maven_maven_repository_href, patchedmaven_maven_repository, opts = {}) ⇒ MavenMavenRepositoryResponse
Update a maven repository Update the entity partially and trigger an asynchronous task if necessary
719 720 721 722 |
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 719 def partial_update(maven_maven_repository_href, patchedmaven_maven_repository, opts = {}) data, _status_code, _headers = partial_update_with_http_info(maven_maven_repository_href, patchedmaven_maven_repository, opts) data end |
#partial_update_with_http_info(maven_maven_repository_href, patchedmaven_maven_repository, opts = {}) ⇒ Array<(MavenMavenRepositoryResponse, Integer, Hash)>
Update a maven repository Update the entity partially and trigger an asynchronous task if necessary
731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 |
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 731 def partial_update_with_http_info(maven_maven_repository_href, patchedmaven_maven_repository, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesMavenApi.partial_update ...' end # verify the required parameter 'maven_maven_repository_href' is set if @api_client.config.client_side_validation && maven_maven_repository_href.nil? fail ArgumentError, "Missing the required parameter 'maven_maven_repository_href' when calling RepositoriesMavenApi.partial_update" end # verify the required parameter 'patchedmaven_maven_repository' is set if @api_client.config.client_side_validation && patchedmaven_maven_repository.nil? fail ArgumentError, "Missing the required parameter 'patchedmaven_maven_repository' when calling RepositoriesMavenApi.partial_update" end # resource path local_var_path = '{maven_maven_repository_href}'.sub('{' + 'maven_maven_repository_href' + '}', CGI.escape(maven_maven_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(patchedmaven_maven_repository) # return_type return_type = opts[:debug_return_type] || 'MavenMavenRepositoryResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"RepositoriesMavenApi.partial_update", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesMavenApi#partial_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#read(maven_maven_repository_href, opts = {}) ⇒ MavenMavenRepositoryResponse
Inspect a maven repository A ViewSet for MavenRepository.
797 798 799 800 |
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 797 def read(maven_maven_repository_href, opts = {}) data, _status_code, _headers = read_with_http_info(maven_maven_repository_href, opts) data end |
#read_with_http_info(maven_maven_repository_href, opts = {}) ⇒ Array<(MavenMavenRepositoryResponse, Integer, Hash)>
Inspect a maven repository A ViewSet for MavenRepository.
810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 |
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 810 def read_with_http_info(maven_maven_repository_href, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesMavenApi.read ...' end # verify the required parameter 'maven_maven_repository_href' is set if @api_client.config.client_side_validation && maven_maven_repository_href.nil? fail ArgumentError, "Missing the required parameter 'maven_maven_repository_href' when calling RepositoriesMavenApi.read" end # resource path local_var_path = '{maven_maven_repository_href}'.sub('{' + 'maven_maven_repository_href' + '}', CGI.escape(maven_maven_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil? query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'MavenMavenRepositoryResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"RepositoriesMavenApi.read", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesMavenApi#read\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#remove_role(maven_maven_repository_href, nested_role, opts = {}) ⇒ NestedRoleResponse
Remove a role Remove a role for this object from users/groups.
868 869 870 871 |
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 868 def remove_role(maven_maven_repository_href, nested_role, opts = {}) data, _status_code, _headers = remove_role_with_http_info(maven_maven_repository_href, nested_role, opts) data end |
#remove_role_with_http_info(maven_maven_repository_href, nested_role, opts = {}) ⇒ Array<(NestedRoleResponse, Integer, Hash)>
Remove a role Remove a role for this object from users/groups.
880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 |
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 880 def remove_role_with_http_info(maven_maven_repository_href, nested_role, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesMavenApi.remove_role ...' end # verify the required parameter 'maven_maven_repository_href' is set if @api_client.config.client_side_validation && maven_maven_repository_href.nil? fail ArgumentError, "Missing the required parameter 'maven_maven_repository_href' when calling RepositoriesMavenApi.remove_role" end # verify the required parameter 'nested_role' is set if @api_client.config.client_side_validation && nested_role.nil? fail ArgumentError, "Missing the required parameter 'nested_role' when calling RepositoriesMavenApi.remove_role" end # resource path local_var_path = '{maven_maven_repository_href}remove_role/'.sub('{' + 'maven_maven_repository_href' + '}', CGI.escape(maven_maven_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(nested_role) # return_type return_type = opts[:debug_return_type] || 'NestedRoleResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"RepositoriesMavenApi.remove_role", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesMavenApi#remove_role\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#repair_metadata(maven_maven_repository_href, opts = {}) ⇒ AsyncOperationResponse
Repair metadata Trigger an asynchronous task to regenerate all maven-metadata.xml files and their checksums for every artifact in the repository.
944 945 946 947 |
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 944 def (maven_maven_repository_href, opts = {}) data, _status_code, _headers = (maven_maven_repository_href, opts) data end |
#repair_metadata_with_http_info(maven_maven_repository_href, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>
Repair metadata Trigger an asynchronous task to regenerate all maven-metadata.xml files and their checksums for every artifact in the repository.
955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 |
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 955 def (maven_maven_repository_href, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesMavenApi.repair_metadata ...' end # verify the required parameter 'maven_maven_repository_href' is set if @api_client.config.client_side_validation && maven_maven_repository_href.nil? fail ArgumentError, "Missing the required parameter 'maven_maven_repository_href' when calling RepositoriesMavenApi.repair_metadata" end # resource path local_var_path = '{maven_maven_repository_href}repair_metadata/'.sub('{' + 'maven_maven_repository_href' + '}', CGI.escape(maven_maven_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'AsyncOperationResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"RepositoriesMavenApi.repair_metadata", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesMavenApi#repair_metadata\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#set_label(maven_maven_repository_href, set_label, opts = {}) ⇒ SetLabelResponse
Set a label Set a single pulp_label on the object to a specific value or null.
1011 1012 1013 1014 |
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 1011 def set_label(maven_maven_repository_href, set_label, opts = {}) data, _status_code, _headers = set_label_with_http_info(maven_maven_repository_href, set_label, opts) data end |
#set_label_with_http_info(maven_maven_repository_href, set_label, opts = {}) ⇒ Array<(SetLabelResponse, Integer, Hash)>
Set a label Set a single pulp_label on the object to a specific value or null.
1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 |
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 1023 def set_label_with_http_info(maven_maven_repository_href, set_label, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesMavenApi.set_label ...' end # verify the required parameter 'maven_maven_repository_href' is set if @api_client.config.client_side_validation && maven_maven_repository_href.nil? fail ArgumentError, "Missing the required parameter 'maven_maven_repository_href' when calling RepositoriesMavenApi.set_label" end # verify the required parameter 'set_label' is set if @api_client.config.client_side_validation && set_label.nil? fail ArgumentError, "Missing the required parameter 'set_label' when calling RepositoriesMavenApi.set_label" end # resource path local_var_path = '{maven_maven_repository_href}set_label/'.sub('{' + 'maven_maven_repository_href' + '}', CGI.escape(maven_maven_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(set_label) # return_type return_type = opts[:debug_return_type] || 'SetLabelResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"RepositoriesMavenApi.set_label", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesMavenApi#set_label\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#unset_label(maven_maven_repository_href, unset_label, opts = {}) ⇒ UnsetLabelResponse
Unset a label Unset a single pulp_label on the object.
1088 1089 1090 1091 |
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 1088 def unset_label(maven_maven_repository_href, unset_label, opts = {}) data, _status_code, _headers = unset_label_with_http_info(maven_maven_repository_href, unset_label, opts) data end |
#unset_label_with_http_info(maven_maven_repository_href, unset_label, opts = {}) ⇒ Array<(UnsetLabelResponse, Integer, Hash)>
Unset a label Unset a single pulp_label on the object.
1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 |
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 1100 def unset_label_with_http_info(maven_maven_repository_href, unset_label, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesMavenApi.unset_label ...' end # verify the required parameter 'maven_maven_repository_href' is set if @api_client.config.client_side_validation && maven_maven_repository_href.nil? fail ArgumentError, "Missing the required parameter 'maven_maven_repository_href' when calling RepositoriesMavenApi.unset_label" end # verify the required parameter 'unset_label' is set if @api_client.config.client_side_validation && unset_label.nil? fail ArgumentError, "Missing the required parameter 'unset_label' when calling RepositoriesMavenApi.unset_label" end # resource path local_var_path = '{maven_maven_repository_href}unset_label/'.sub('{' + 'maven_maven_repository_href' + '}', CGI.escape(maven_maven_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(unset_label) # return_type return_type = opts[:debug_return_type] || 'UnsetLabelResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"RepositoriesMavenApi.unset_label", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesMavenApi#unset_label\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update(maven_maven_repository_href, maven_maven_repository, opts = {}) ⇒ MavenMavenRepositoryResponse
Update a maven repository Update the entity and trigger an asynchronous task if necessary
1165 1166 1167 1168 |
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 1165 def update(maven_maven_repository_href, maven_maven_repository, opts = {}) data, _status_code, _headers = update_with_http_info(maven_maven_repository_href, maven_maven_repository, opts) data end |
#update_with_http_info(maven_maven_repository_href, maven_maven_repository, opts = {}) ⇒ Array<(MavenMavenRepositoryResponse, Integer, Hash)>
Update a maven repository Update the entity and trigger an asynchronous task if necessary
1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 1229 1230 1231 1232 1233 |
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 1177 def update_with_http_info(maven_maven_repository_href, maven_maven_repository, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RepositoriesMavenApi.update ...' end # verify the required parameter 'maven_maven_repository_href' is set if @api_client.config.client_side_validation && maven_maven_repository_href.nil? fail ArgumentError, "Missing the required parameter 'maven_maven_repository_href' when calling RepositoriesMavenApi.update" end # verify the required parameter 'maven_maven_repository' is set if @api_client.config.client_side_validation && maven_maven_repository.nil? fail ArgumentError, "Missing the required parameter 'maven_maven_repository' when calling RepositoriesMavenApi.update" end # resource path local_var_path = '{maven_maven_repository_href}'.sub('{' + 'maven_maven_repository_href' + '}', CGI.escape(maven_maven_repository_href.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'X-Task-Diagnostics'] = @api_client.build_collection_param(opts[:'x_task_diagnostics'], :csv) if !opts[:'x_task_diagnostics'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(maven_maven_repository) # return_type return_type = opts[:debug_return_type] || 'MavenMavenRepositoryResponse' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth'] = opts.merge( :operation => :"RepositoriesMavenApi.update", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RepositoriesMavenApi#update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |