Class: PulpMavenClient::MavenMavenPackageResponse
- Inherits:
-
Object
- Object
- PulpMavenClient::MavenMavenPackageResponse
- Defined in:
- lib/pulp_maven_client/models/maven_maven_package_response.rb
Overview
A read-only Serializer for MavenPackage.
Instance Attribute Summary collapse
-
#artifact_id ⇒ Object
Artifact Id of the package.
-
#dependencies ⇒ Object
Returns the value of attribute dependencies.
-
#description ⇒ Object
Description from the POM.
-
#group_id ⇒ Object
Group Id of the package.
-
#licenses ⇒ Object
Returns the value of attribute licenses.
-
#name ⇒ Object
Human-readable name from the POM.
-
#packaging ⇒ Object
Packaging type (jar, war, pom, etc).
-
#prn ⇒ Object
The Pulp Resource Name (PRN).
-
#pulp_created ⇒ Object
Timestamp of creation.
-
#pulp_href ⇒ Object
Returns the value of attribute pulp_href.
-
#pulp_labels ⇒ Object
A dictionary of arbitrary key/value pairs used to describe a specific Content instance.
-
#pulp_last_updated ⇒ Object
Timestamp of the last time this resource was updated.
-
#scm_url ⇒ Object
Source control URL from the POM.
-
#url ⇒ Object
Project URL from the POM.
-
#version ⇒ Object
Version of the package.
-
#vuln_report ⇒ Object
Returns the value of attribute vuln_report.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MavenMavenPackageResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ MavenMavenPackageResponse
Initializes the object
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/pulp_maven_client/models/maven_maven_package_response.rb', line 127 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PulpMavenClient::MavenMavenPackageResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PulpMavenClient::MavenMavenPackageResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'pulp_href') self.pulp_href = attributes[:'pulp_href'] end if attributes.key?(:'prn') self.prn = attributes[:'prn'] end if attributes.key?(:'pulp_created') self.pulp_created = attributes[:'pulp_created'] end if attributes.key?(:'pulp_last_updated') self.pulp_last_updated = attributes[:'pulp_last_updated'] end if attributes.key?(:'pulp_labels') if (value = attributes[:'pulp_labels']).is_a?(Hash) self.pulp_labels = value end end if attributes.key?(:'vuln_report') self.vuln_report = attributes[:'vuln_report'] end if attributes.key?(:'group_id') self.group_id = attributes[:'group_id'] end if attributes.key?(:'artifact_id') self.artifact_id = attributes[:'artifact_id'] end if attributes.key?(:'version') self.version = attributes[:'version'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'packaging') self.packaging = attributes[:'packaging'] end if attributes.key?(:'url') self.url = attributes[:'url'] end if attributes.key?(:'licenses') self.licenses = attributes[:'licenses'] end if attributes.key?(:'dependencies') self.dependencies = attributes[:'dependencies'] end if attributes.key?(:'scm_url') self.scm_url = attributes[:'scm_url'] end end |
Instance Attribute Details
#artifact_id ⇒ Object
Artifact Id of the package.
39 40 41 |
# File 'lib/pulp_maven_client/models/maven_maven_package_response.rb', line 39 def artifact_id @artifact_id end |
#dependencies ⇒ Object
Returns the value of attribute dependencies.
58 59 60 |
# File 'lib/pulp_maven_client/models/maven_maven_package_response.rb', line 58 def dependencies @dependencies end |
#description ⇒ Object
Description from the POM.
48 49 50 |
# File 'lib/pulp_maven_client/models/maven_maven_package_response.rb', line 48 def description @description end |
#group_id ⇒ Object
Group Id of the package.
36 37 38 |
# File 'lib/pulp_maven_client/models/maven_maven_package_response.rb', line 36 def group_id @group_id end |
#licenses ⇒ Object
Returns the value of attribute licenses.
56 57 58 |
# File 'lib/pulp_maven_client/models/maven_maven_package_response.rb', line 56 def licenses @licenses end |
#name ⇒ Object
Human-readable name from the POM.
45 46 47 |
# File 'lib/pulp_maven_client/models/maven_maven_package_response.rb', line 45 def name @name end |
#packaging ⇒ Object
Packaging type (jar, war, pom, etc).
51 52 53 |
# File 'lib/pulp_maven_client/models/maven_maven_package_response.rb', line 51 def packaging @packaging end |
#prn ⇒ Object
The Pulp Resource Name (PRN).
22 23 24 |
# File 'lib/pulp_maven_client/models/maven_maven_package_response.rb', line 22 def prn @prn end |
#pulp_created ⇒ Object
Timestamp of creation.
25 26 27 |
# File 'lib/pulp_maven_client/models/maven_maven_package_response.rb', line 25 def pulp_created @pulp_created end |
#pulp_href ⇒ Object
Returns the value of attribute pulp_href.
19 20 21 |
# File 'lib/pulp_maven_client/models/maven_maven_package_response.rb', line 19 def pulp_href @pulp_href end |
#pulp_labels ⇒ Object
A dictionary of arbitrary key/value pairs used to describe a specific Content instance.
31 32 33 |
# File 'lib/pulp_maven_client/models/maven_maven_package_response.rb', line 31 def pulp_labels @pulp_labels end |
#pulp_last_updated ⇒ Object
Timestamp of the last time this resource was updated. Note: for immutable resources - like content, repository versions, and publication - pulp_created and pulp_last_updated dates will be the same.
28 29 30 |
# File 'lib/pulp_maven_client/models/maven_maven_package_response.rb', line 28 def pulp_last_updated @pulp_last_updated end |
#scm_url ⇒ Object
Source control URL from the POM.
61 62 63 |
# File 'lib/pulp_maven_client/models/maven_maven_package_response.rb', line 61 def scm_url @scm_url end |
#url ⇒ Object
Project URL from the POM.
54 55 56 |
# File 'lib/pulp_maven_client/models/maven_maven_package_response.rb', line 54 def url @url end |
#version ⇒ Object
Version of the package.
42 43 44 |
# File 'lib/pulp_maven_client/models/maven_maven_package_response.rb', line 42 def version @version end |
#vuln_report ⇒ Object
Returns the value of attribute vuln_report.
33 34 35 |
# File 'lib/pulp_maven_client/models/maven_maven_package_response.rb', line 33 def vuln_report @vuln_report end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/pulp_maven_client/models/maven_maven_package_response.rb', line 284 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = PulpMavenClient.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
86 87 88 |
# File 'lib/pulp_maven_client/models/maven_maven_package_response.rb', line 86 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/pulp_maven_client/models/maven_maven_package_response.rb', line 64 def self.attribute_map { :'pulp_href' => :'pulp_href', :'prn' => :'prn', :'pulp_created' => :'pulp_created', :'pulp_last_updated' => :'pulp_last_updated', :'pulp_labels' => :'pulp_labels', :'vuln_report' => :'vuln_report', :'group_id' => :'group_id', :'artifact_id' => :'artifact_id', :'version' => :'version', :'name' => :'name', :'description' => :'description', :'packaging' => :'packaging', :'url' => :'url', :'licenses' => :'licenses', :'dependencies' => :'dependencies', :'scm_url' => :'scm_url' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 |
# File 'lib/pulp_maven_client/models/maven_maven_package_response.rb', line 260 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/pulp_maven_client/models/maven_maven_package_response.rb', line 113 def self.openapi_nullable Set.new([ :'name', :'description', :'packaging', :'url', :'licenses', :'dependencies', :'scm_url' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/pulp_maven_client/models/maven_maven_package_response.rb', line 91 def self.openapi_types { :'pulp_href' => :'String', :'prn' => :'String', :'pulp_created' => :'Time', :'pulp_last_updated' => :'Time', :'pulp_labels' => :'Hash<String, String>', :'vuln_report' => :'String', :'group_id' => :'String', :'artifact_id' => :'String', :'version' => :'String', :'name' => :'String', :'description' => :'String', :'packaging' => :'String', :'url' => :'String', :'licenses' => :'Object', :'dependencies' => :'Object', :'scm_url' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/pulp_maven_client/models/maven_maven_package_response.rb', line 224 def ==(o) return true if self.equal?(o) self.class == o.class && pulp_href == o.pulp_href && prn == o.prn && pulp_created == o.pulp_created && pulp_last_updated == o.pulp_last_updated && pulp_labels == o.pulp_labels && vuln_report == o.vuln_report && group_id == o.group_id && artifact_id == o.artifact_id && version == o.version && name == o.name && description == o.description && packaging == o.packaging && url == o.url && licenses == o.licenses && dependencies == o.dependencies && scm_url == o.scm_url end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
355 356 357 358 359 360 361 362 363 364 365 366 367 |
# File 'lib/pulp_maven_client/models/maven_maven_package_response.rb', line 355 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
247 248 249 |
# File 'lib/pulp_maven_client/models/maven_maven_package_response.rb', line 247 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
253 254 255 |
# File 'lib/pulp_maven_client/models/maven_maven_package_response.rb', line 253 def hash [pulp_href, prn, pulp_created, pulp_last_updated, pulp_labels, vuln_report, group_id, artifact_id, version, name, description, packaging, url, licenses, dependencies, scm_url].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
209 210 211 212 213 |
# File 'lib/pulp_maven_client/models/maven_maven_package_response.rb', line 209 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
331 332 333 |
# File 'lib/pulp_maven_client/models/maven_maven_package_response.rb', line 331 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/pulp_maven_client/models/maven_maven_package_response.rb', line 337 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
325 326 327 |
# File 'lib/pulp_maven_client/models/maven_maven_package_response.rb', line 325 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
217 218 219 220 |
# File 'lib/pulp_maven_client/models/maven_maven_package_response.rb', line 217 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |