Class: PulpMavenClient::RepositoriesMavenApi

Inherits:
Object
  • Object
show all
Defined in:
lib/pulp_maven_client/api/repositories_maven_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ RepositoriesMavenApi



19
20
21
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#add_cached_content(maven_maven_repository_href, repository_add_cached_content, opts = {}) ⇒ AsyncOperationResponse

Add cached content Trigger an asynchronous task to add cached content to a repository.



28
29
30
31
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 28

def add_cached_content(maven_maven_repository_href, repository_add_cached_content, opts = {})
  data, _status_code, _headers = add_cached_content_with_http_info(maven_maven_repository_href, repository_add_cached_content, opts)
  data
end

#add_cached_content_with_http_info(maven_maven_repository_href, repository_add_cached_content, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>

Add cached content Trigger an asynchronous task to add cached content to a repository.



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 39

def add_cached_content_with_http_info(maven_maven_repository_href, repository_add_cached_content, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RepositoriesMavenApi.add_cached_content ...'
  end
  # verify the required parameter 'maven_maven_repository_href' is set
  if @api_client.config.client_side_validation && maven_maven_repository_href.nil?
    fail ArgumentError, "Missing the required parameter 'maven_maven_repository_href' when calling RepositoriesMavenApi.add_cached_content"
  end
  # verify the required parameter 'repository_add_cached_content' is set
  if @api_client.config.client_side_validation && repository_add_cached_content.nil?
    fail ArgumentError, "Missing the required parameter 'repository_add_cached_content' when calling RepositoriesMavenApi.add_cached_content"
  end
  # resource path
  local_var_path = '{maven_maven_repository_href}add_cached_content/'.sub('{' + 'maven_maven_repository_href' + '}', CGI.escape(maven_maven_repository_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(repository_add_cached_content) 

  # return_type
  return_type = opts[:return_type] || 'AsyncOperationResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RepositoriesMavenApi#add_cached_content\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#create(maven_maven_repository, opts = {}) ⇒ MavenMavenRepositoryResponse

Create a maven repository A ViewSet for MavenRemote.



97
98
99
100
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 97

def create(maven_maven_repository, opts = {})
  data, _status_code, _headers = create_with_http_info(maven_maven_repository, opts)
  data
end

#create_with_http_info(maven_maven_repository, opts = {}) ⇒ Array<(MavenMavenRepositoryResponse, Integer, Hash)>

Create a maven repository A ViewSet for MavenRemote.



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 107

def create_with_http_info(maven_maven_repository, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RepositoriesMavenApi.create ...'
  end
  # verify the required parameter 'maven_maven_repository' is set
  if @api_client.config.client_side_validation && maven_maven_repository.nil?
    fail ArgumentError, "Missing the required parameter 'maven_maven_repository' when calling RepositoriesMavenApi.create"
  end
  # resource path
  local_var_path = '/pulp/api/v3/repositories/maven/maven/'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(maven_maven_repository) 

  # return_type
  return_type = opts[:return_type] || 'MavenMavenRepositoryResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RepositoriesMavenApi#create\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete(maven_maven_repository_href, opts = {}) ⇒ AsyncOperationResponse

Delete a maven repository Trigger an asynchronous delete task



161
162
163
164
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 161

def delete(maven_maven_repository_href, opts = {})
  data, _status_code, _headers = delete_with_http_info(maven_maven_repository_href, opts)
  data
end

#delete_with_http_info(maven_maven_repository_href, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>

Delete a maven repository Trigger an asynchronous delete task



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 171

def delete_with_http_info(maven_maven_repository_href, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RepositoriesMavenApi.delete ...'
  end
  # verify the required parameter 'maven_maven_repository_href' is set
  if @api_client.config.client_side_validation && maven_maven_repository_href.nil?
    fail ArgumentError, "Missing the required parameter 'maven_maven_repository_href' when calling RepositoriesMavenApi.delete"
  end
  # resource path
  local_var_path = '{maven_maven_repository_href}'.sub('{' + 'maven_maven_repository_href' + '}', CGI.escape(maven_maven_repository_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] || 'AsyncOperationResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RepositoriesMavenApi#delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list(opts = {}) ⇒ PaginatedmavenMavenRepositoryResponseList

List maven repositorys A ViewSet for MavenRemote.

Options Hash (opts):

  • :latest_with_content (String)

    Content Unit referenced by HREF/PRN

  • :limit (Integer)

    Number of results to return per page.

  • :name (String)

    Filter results where name matches value

  • :name__contains (String)

    Filter results where name contains value

  • :name__icontains (String)

    Filter results where name contains value

  • :name__iexact (String)

    Filter results where name matches value

  • :name__in (Array<String>)

    Filter results where name is in a comma-separated list of values

  • :name__iregex (String)

    Filter results where name matches regex value

  • :name__istartswith (String)

    Filter results where name starts with value

  • :name__regex (String)

    Filter results where name matches regex value

  • :name__startswith (String)

    Filter results where name starts with value

  • :offset (Integer)

    The initial index from which to return the results.

  • :ordering (Array<String>)

    Ordering * &#x60;pulp_id&#x60; - Pulp id * &#x60;-pulp_id&#x60; - Pulp id (descending) * &#x60;pulp_created&#x60; - Pulp created * &#x60;-pulp_created&#x60; - Pulp created (descending) * &#x60;pulp_last_updated&#x60; - Pulp last updated * &#x60;-pulp_last_updated&#x60; - Pulp last updated (descending) * &#x60;pulp_type&#x60; - Pulp type * &#x60;-pulp_type&#x60; - Pulp type (descending) * &#x60;name&#x60; - Name * &#x60;-name&#x60; - Name (descending) * &#x60;pulp_labels&#x60; - Pulp labels * &#x60;-pulp_labels&#x60; - Pulp labels (descending) * &#x60;description&#x60; - Description * &#x60;-description&#x60; - Description (descending) * &#x60;next_version&#x60; - Next version * &#x60;-next_version&#x60; - Next version (descending) * &#x60;retain_repo_versions&#x60; - Retain repo versions * &#x60;-retain_repo_versions&#x60; - Retain repo versions (descending) * &#x60;user_hidden&#x60; - User hidden * &#x60;-user_hidden&#x60; - User hidden (descending) * &#x60;pk&#x60; - Pk * &#x60;-pk&#x60; - Pk (descending)

  • :prn__in (Array<String>)

    Multiple values may be separated by commas.

  • :pulp_href__in (Array<String>)

    Multiple values may be separated by commas.

  • :pulp_id__in (Array<String>)

    Multiple values may be separated by commas.

  • :pulp_label_select (String)

    Filter labels by search string

  • :q (String)

    Filter results by using NOT, AND and OR operations on other filters

  • :remote (String)

    Foreign Key referenced by HREF

  • :retain_repo_versions (Integer)

    Filter results where retain_repo_versions matches value

  • :retain_repo_versions__gt (Integer)

    Filter results where retain_repo_versions is greater than value

  • :retain_repo_versions__gte (Integer)

    Filter results where retain_repo_versions is greater than or equal to value

  • :retain_repo_versions__isnull (Boolean)

    Filter results where retain_repo_versions has a null value

  • :retain_repo_versions__lt (Integer)

    Filter results where retain_repo_versions is less than value

  • :retain_repo_versions__lte (Integer)

    Filter results where retain_repo_versions is less than or equal to value

  • :retain_repo_versions__ne (Integer)

    Filter results where retain_repo_versions not equal to value

  • :retain_repo_versions__range (Array<Integer>)

    Filter results where retain_repo_versions is between two comma separated values

  • :with_content (String)

    Content Unit referenced by HREF/PRN

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.



252
253
254
255
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 252

def list(opts = {})
  data, _status_code, _headers = list_with_http_info(opts)
  data
end

#list_with_http_info(opts = {}) ⇒ Array<(PaginatedmavenMavenRepositoryResponseList, Integer, Hash)>

List maven repositorys A ViewSet for MavenRemote.

Options Hash (opts):

  • :latest_with_content (String)

    Content Unit referenced by HREF/PRN

  • :limit (Integer)

    Number of results to return per page.

  • :name (String)

    Filter results where name matches value

  • :name__contains (String)

    Filter results where name contains value

  • :name__icontains (String)

    Filter results where name contains value

  • :name__iexact (String)

    Filter results where name matches value

  • :name__in (Array<String>)

    Filter results where name is in a comma-separated list of values

  • :name__iregex (String)

    Filter results where name matches regex value

  • :name__istartswith (String)

    Filter results where name starts with value

  • :name__regex (String)

    Filter results where name matches regex value

  • :name__startswith (String)

    Filter results where name starts with value

  • :offset (Integer)

    The initial index from which to return the results.

  • :ordering (Array<String>)

    Ordering * &#x60;pulp_id&#x60; - Pulp id * &#x60;-pulp_id&#x60; - Pulp id (descending) * &#x60;pulp_created&#x60; - Pulp created * &#x60;-pulp_created&#x60; - Pulp created (descending) * &#x60;pulp_last_updated&#x60; - Pulp last updated * &#x60;-pulp_last_updated&#x60; - Pulp last updated (descending) * &#x60;pulp_type&#x60; - Pulp type * &#x60;-pulp_type&#x60; - Pulp type (descending) * &#x60;name&#x60; - Name * &#x60;-name&#x60; - Name (descending) * &#x60;pulp_labels&#x60; - Pulp labels * &#x60;-pulp_labels&#x60; - Pulp labels (descending) * &#x60;description&#x60; - Description * &#x60;-description&#x60; - Description (descending) * &#x60;next_version&#x60; - Next version * &#x60;-next_version&#x60; - Next version (descending) * &#x60;retain_repo_versions&#x60; - Retain repo versions * &#x60;-retain_repo_versions&#x60; - Retain repo versions (descending) * &#x60;user_hidden&#x60; - User hidden * &#x60;-user_hidden&#x60; - User hidden (descending) * &#x60;pk&#x60; - Pk * &#x60;-pk&#x60; - Pk (descending)

  • :prn__in (Array<String>)

    Multiple values may be separated by commas.

  • :pulp_href__in (Array<String>)

    Multiple values may be separated by commas.

  • :pulp_id__in (Array<String>)

    Multiple values may be separated by commas.

  • :pulp_label_select (String)

    Filter labels by search string

  • :q (String)

    Filter results by using NOT, AND and OR operations on other filters

  • :remote (String)

    Foreign Key referenced by HREF

  • :retain_repo_versions (Integer)

    Filter results where retain_repo_versions matches value

  • :retain_repo_versions__gt (Integer)

    Filter results where retain_repo_versions is greater than value

  • :retain_repo_versions__gte (Integer)

    Filter results where retain_repo_versions is greater than or equal to value

  • :retain_repo_versions__isnull (Boolean)

    Filter results where retain_repo_versions has a null value

  • :retain_repo_versions__lt (Integer)

    Filter results where retain_repo_versions is less than value

  • :retain_repo_versions__lte (Integer)

    Filter results where retain_repo_versions is less than or equal to value

  • :retain_repo_versions__ne (Integer)

    Filter results where retain_repo_versions not equal to value

  • :retain_repo_versions__range (Array<Integer>)

    Filter results where retain_repo_versions is between two comma separated values

  • :with_content (String)

    Content Unit referenced by HREF/PRN

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.



291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 291

def list_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RepositoriesMavenApi.list ...'
  end
  allowable_values = ["-description", "-name", "-next_version", "-pk", "-pulp_created", "-pulp_id", "-pulp_labels", "-pulp_last_updated", "-pulp_type", "-retain_repo_versions", "-user_hidden", "description", "name", "next_version", "pk", "pulp_created", "pulp_id", "pulp_labels", "pulp_last_updated", "pulp_type", "retain_repo_versions", "user_hidden"]
  if @api_client.config.client_side_validation && opts[:'ordering'] && !opts[:'ordering'].all? { |item| allowable_values.include?(item) }
    fail ArgumentError, "invalid value for \"ordering\", must include one of #{allowable_values}"
  end
  # resource path
  local_var_path = '/pulp/api/v3/repositories/maven/maven/'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'latest_with_content'] = opts[:'latest_with_content'] if !opts[:'latest_with_content'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'name'] = opts[:'name'] if !opts[:'name'].nil?
  query_params[:'name__contains'] = opts[:'name__contains'] if !opts[:'name__contains'].nil?
  query_params[:'name__icontains'] = opts[:'name__icontains'] if !opts[:'name__icontains'].nil?
  query_params[:'name__iexact'] = opts[:'name__iexact'] if !opts[:'name__iexact'].nil?
  query_params[:'name__in'] = @api_client.build_collection_param(opts[:'name__in'], :csv) if !opts[:'name__in'].nil?
  query_params[:'name__iregex'] = opts[:'name__iregex'] if !opts[:'name__iregex'].nil?
  query_params[:'name__istartswith'] = opts[:'name__istartswith'] if !opts[:'name__istartswith'].nil?
  query_params[:'name__regex'] = opts[:'name__regex'] if !opts[:'name__regex'].nil?
  query_params[:'name__startswith'] = opts[:'name__startswith'] if !opts[:'name__startswith'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'ordering'] = @api_client.build_collection_param(opts[:'ordering'], :csv) if !opts[:'ordering'].nil?
  query_params[:'prn__in'] = @api_client.build_collection_param(opts[:'prn__in'], :csv) if !opts[:'prn__in'].nil?
  query_params[:'pulp_href__in'] = @api_client.build_collection_param(opts[:'pulp_href__in'], :csv) if !opts[:'pulp_href__in'].nil?
  query_params[:'pulp_id__in'] = @api_client.build_collection_param(opts[:'pulp_id__in'], :csv) if !opts[:'pulp_id__in'].nil?
  query_params[:'pulp_label_select'] = opts[:'pulp_label_select'] if !opts[:'pulp_label_select'].nil?
  query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil?
  query_params[:'remote'] = opts[:'remote'] if !opts[:'remote'].nil?
  query_params[:'retain_repo_versions'] = opts[:'retain_repo_versions'] if !opts[:'retain_repo_versions'].nil?
  query_params[:'retain_repo_versions__gt'] = opts[:'retain_repo_versions__gt'] if !opts[:'retain_repo_versions__gt'].nil?
  query_params[:'retain_repo_versions__gte'] = opts[:'retain_repo_versions__gte'] if !opts[:'retain_repo_versions__gte'].nil?
  query_params[:'retain_repo_versions__isnull'] = opts[:'retain_repo_versions__isnull'] if !opts[:'retain_repo_versions__isnull'].nil?
  query_params[:'retain_repo_versions__lt'] = opts[:'retain_repo_versions__lt'] if !opts[:'retain_repo_versions__lt'].nil?
  query_params[:'retain_repo_versions__lte'] = opts[:'retain_repo_versions__lte'] if !opts[:'retain_repo_versions__lte'].nil?
  query_params[:'retain_repo_versions__ne'] = opts[:'retain_repo_versions__ne'] if !opts[:'retain_repo_versions__ne'].nil?
  query_params[:'retain_repo_versions__range'] = @api_client.build_collection_param(opts[:'retain_repo_versions__range'], :csv) if !opts[:'retain_repo_versions__range'].nil?
  query_params[:'with_content'] = opts[:'with_content'] if !opts[:'with_content'].nil?
  query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil?
  query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] || 'PaginatedmavenMavenRepositoryResponseList' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RepositoriesMavenApi#list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#partial_update(maven_maven_repository_href, patchedmaven_maven_repository, opts = {}) ⇒ AsyncOperationResponse

Update a maven repository Trigger an asynchronous partial update task



374
375
376
377
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 374

def partial_update(maven_maven_repository_href, patchedmaven_maven_repository, opts = {})
  data, _status_code, _headers = partial_update_with_http_info(maven_maven_repository_href, patchedmaven_maven_repository, opts)
  data
end

#partial_update_with_http_info(maven_maven_repository_href, patchedmaven_maven_repository, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>

Update a maven repository Trigger an asynchronous partial update task



385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 385

def partial_update_with_http_info(maven_maven_repository_href, patchedmaven_maven_repository, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RepositoriesMavenApi.partial_update ...'
  end
  # verify the required parameter 'maven_maven_repository_href' is set
  if @api_client.config.client_side_validation && maven_maven_repository_href.nil?
    fail ArgumentError, "Missing the required parameter 'maven_maven_repository_href' when calling RepositoriesMavenApi.partial_update"
  end
  # verify the required parameter 'patchedmaven_maven_repository' is set
  if @api_client.config.client_side_validation && patchedmaven_maven_repository.nil?
    fail ArgumentError, "Missing the required parameter 'patchedmaven_maven_repository' when calling RepositoriesMavenApi.partial_update"
  end
  # resource path
  local_var_path = '{maven_maven_repository_href}'.sub('{' + 'maven_maven_repository_href' + '}', CGI.escape(maven_maven_repository_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(patchedmaven_maven_repository) 

  # return_type
  return_type = opts[:return_type] || 'AsyncOperationResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RepositoriesMavenApi#partial_update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#read(maven_maven_repository_href, opts = {}) ⇒ MavenMavenRepositoryResponse

Inspect a maven repository A ViewSet for MavenRemote.

Options Hash (opts):

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.



445
446
447
448
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 445

def read(maven_maven_repository_href, opts = {})
  data, _status_code, _headers = read_with_http_info(maven_maven_repository_href, opts)
  data
end

#read_with_http_info(maven_maven_repository_href, opts = {}) ⇒ Array<(MavenMavenRepositoryResponse, Integer, Hash)>

Inspect a maven repository A ViewSet for MavenRemote.

Options Hash (opts):

  • :fields (Array<String>)

    A list of fields to include in the response.

  • :exclude_fields (Array<String>)

    A list of fields to exclude from the response.



457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 457

def read_with_http_info(maven_maven_repository_href, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RepositoriesMavenApi.read ...'
  end
  # verify the required parameter 'maven_maven_repository_href' is set
  if @api_client.config.client_side_validation && maven_maven_repository_href.nil?
    fail ArgumentError, "Missing the required parameter 'maven_maven_repository_href' when calling RepositoriesMavenApi.read"
  end
  # resource path
  local_var_path = '{maven_maven_repository_href}'.sub('{' + 'maven_maven_repository_href' + '}', CGI.escape(maven_maven_repository_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'fields'] = @api_client.build_collection_param(opts[:'fields'], :multi) if !opts[:'fields'].nil?
  query_params[:'exclude_fields'] = @api_client.build_collection_param(opts[:'exclude_fields'], :multi) if !opts[:'exclude_fields'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] 

  # return_type
  return_type = opts[:return_type] || 'MavenMavenRepositoryResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RepositoriesMavenApi#read\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#set_label(maven_maven_repository_href, set_label, opts = {}) ⇒ SetLabelResponse

Set a label Set a single pulp_label on the object to a specific value or null.



512
513
514
515
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 512

def set_label(maven_maven_repository_href, set_label, opts = {})
  data, _status_code, _headers = set_label_with_http_info(maven_maven_repository_href, set_label, opts)
  data
end

#set_label_with_http_info(maven_maven_repository_href, set_label, opts = {}) ⇒ Array<(SetLabelResponse, Integer, Hash)>

Set a label Set a single pulp_label on the object to a specific value or null.



523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 523

def set_label_with_http_info(maven_maven_repository_href, set_label, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RepositoriesMavenApi.set_label ...'
  end
  # verify the required parameter 'maven_maven_repository_href' is set
  if @api_client.config.client_side_validation && maven_maven_repository_href.nil?
    fail ArgumentError, "Missing the required parameter 'maven_maven_repository_href' when calling RepositoriesMavenApi.set_label"
  end
  # verify the required parameter 'set_label' is set
  if @api_client.config.client_side_validation && set_label.nil?
    fail ArgumentError, "Missing the required parameter 'set_label' when calling RepositoriesMavenApi.set_label"
  end
  # resource path
  local_var_path = '{maven_maven_repository_href}set_label/'.sub('{' + 'maven_maven_repository_href' + '}', CGI.escape(maven_maven_repository_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(set_label) 

  # return_type
  return_type = opts[:return_type] || 'SetLabelResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RepositoriesMavenApi#set_label\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#unset_label(maven_maven_repository_href, unset_label, opts = {}) ⇒ UnsetLabelResponse

Unset a label Unset a single pulp_label on the object.



582
583
584
585
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 582

def unset_label(maven_maven_repository_href, unset_label, opts = {})
  data, _status_code, _headers = unset_label_with_http_info(maven_maven_repository_href, unset_label, opts)
  data
end

#unset_label_with_http_info(maven_maven_repository_href, unset_label, opts = {}) ⇒ Array<(UnsetLabelResponse, Integer, Hash)>

Unset a label Unset a single pulp_label on the object.



593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 593

def unset_label_with_http_info(maven_maven_repository_href, unset_label, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RepositoriesMavenApi.unset_label ...'
  end
  # verify the required parameter 'maven_maven_repository_href' is set
  if @api_client.config.client_side_validation && maven_maven_repository_href.nil?
    fail ArgumentError, "Missing the required parameter 'maven_maven_repository_href' when calling RepositoriesMavenApi.unset_label"
  end
  # verify the required parameter 'unset_label' is set
  if @api_client.config.client_side_validation && unset_label.nil?
    fail ArgumentError, "Missing the required parameter 'unset_label' when calling RepositoriesMavenApi.unset_label"
  end
  # resource path
  local_var_path = '{maven_maven_repository_href}unset_label/'.sub('{' + 'maven_maven_repository_href' + '}', CGI.escape(maven_maven_repository_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(unset_label) 

  # return_type
  return_type = opts[:return_type] || 'UnsetLabelResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RepositoriesMavenApi#unset_label\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update(maven_maven_repository_href, maven_maven_repository, opts = {}) ⇒ AsyncOperationResponse

Update a maven repository Trigger an asynchronous update task



652
653
654
655
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 652

def update(maven_maven_repository_href, maven_maven_repository, opts = {})
  data, _status_code, _headers = update_with_http_info(maven_maven_repository_href, maven_maven_repository, opts)
  data
end

#update_with_http_info(maven_maven_repository_href, maven_maven_repository, opts = {}) ⇒ Array<(AsyncOperationResponse, Integer, Hash)>

Update a maven repository Trigger an asynchronous update task



663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
# File 'lib/pulp_maven_client/api/repositories_maven_api.rb', line 663

def update_with_http_info(maven_maven_repository_href, maven_maven_repository, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RepositoriesMavenApi.update ...'
  end
  # verify the required parameter 'maven_maven_repository_href' is set
  if @api_client.config.client_side_validation && maven_maven_repository_href.nil?
    fail ArgumentError, "Missing the required parameter 'maven_maven_repository_href' when calling RepositoriesMavenApi.update"
  end
  # verify the required parameter 'maven_maven_repository' is set
  if @api_client.config.client_side_validation && maven_maven_repository.nil?
    fail ArgumentError, "Missing the required parameter 'maven_maven_repository' when calling RepositoriesMavenApi.update"
  end
  # resource path
  local_var_path = '{maven_maven_repository_href}'.sub('{' + 'maven_maven_repository_href' + '}', CGI.escape(maven_maven_repository_href.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json', 'application/x-www-form-urlencoded', 'multipart/form-data'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:body] || @api_client.object_to_http_body(maven_maven_repository) 

  # return_type
  return_type = opts[:return_type] || 'AsyncOperationResponse' 

  # auth_names
  auth_names = opts[:auth_names] || ['basicAuth']

  new_options = opts.merge(
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PUT, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RepositoriesMavenApi#update\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end